Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/openssl/openssl.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatt Caswell <matt@openssl.org>2015-01-30 16:46:43 +0300
committerMatt Caswell <matt@openssl.org>2015-03-26 16:53:07 +0300
commit52e1d7b152a92d4fc2c3704a0129ec0ee0ce5e21 (patch)
tree3a9ee6dfbcd3c69a496c42d2d0aed810433f1858 /ssl/s3_pkt.c
parent8e3f0c988fabf60b65f7109b7f47daec0fde9c39 (diff)
Create a RECORD_LAYER structure and move read_ahead into it.
Reviewed-by: Richard Levitte <levitte@openssl.org>
Diffstat (limited to 'ssl/s3_pkt.c')
-rw-r--r--ssl/s3_pkt.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ssl/s3_pkt.c b/ssl/s3_pkt.c
index 4f81f1a222..a196a427f2 100644
--- a/ssl/s3_pkt.c
+++ b/ssl/s3_pkt.c
@@ -142,7 +142,7 @@ int ssl3_read_n(SSL *s, int n, int max, int extend)
* If extend == 0, obtain new n-byte packet; if extend == 1, increase
* packet by another n bytes. The packet will be in the sub-array of
* s->s3->rbuf.buf specified by s->packet and s->packet_length. (If
* s->read_ahead is set, 'max' bytes may be stored in rbuf [plus
* s->packet_length bytes if extend == 1].)
*/
int i, len, left;
@@ -232,7 +232,7 @@ int ssl3_read_n(SSL *s, int n, int max, int extend)
}
/* We always act like read_ahead is set for DTLS */
- if (!s->read_ahead && !SSL_IS_DTLS(s))
+ if (!RECORD_LAYER_get_read_ahead(&s->rlayer) && !SSL_IS_DTLS(s))
/* ignore max parameter */
max = n;
else {
@@ -142,7 +142,7 @@ int ssl3_read_n(SSL *s, int n, int max, int extend)
* packet by another n bytes. The packet will be in the sub-array of
* s->s3->rbuf.buf specified by s->packet and s->packet_length. (If
- * s->read_ahead is set, 'max' bytes may be stored in rbuf [plus
+ * s->rlayer.read_ahead is set, 'max' bytes may be stored in rbuf [plus
* s->packet_length bytes if extend == 1].)
*/